@@ -12,7 +12,8 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 from scipy.optimize import curve_fit, OptimizeWarning
-from covsirphy.cleaning import Term, JHUData, ExampleData
+from covsirphy.analysis.example_data import ExampleData
+from covsirphy.cleaning import Term, JHUData
 
 
 class Trend(Term):
